@@ -278,7 +278,7 @@ pub fn run<B: Buffer>(state: &mut Ed<'_,B>, ui: &mut dyn UI, command: &str)
                 else {
                   sel.0
                 };
-                let end = start + input.len();
+                let end = start + input.len().saturating_sub(1); // since the selection bounds are inclusive
                 state.buffer.insert(&mut input, start)?;
                 Some((start, end))
               }
@@ -288,7 +288,7 @@ pub fn run<B: Buffer>(state: &mut Ed<'_,B>, ui: &mut dyn UI, command: &str)
               }
             }
             'c' => {
-              let end = sel.0 + input.len();
+              let end = sel.0 + input.len(); // Not -1 since 'c' has deleted the start line itself
               state.buffer.change(&mut input, sel)?;
               if input.len() != 0 {
                 Some((sel.0, end))
@@ -407,7 +407,8 @@ pub fn run<B: Buffer>(state: &mut Ed<'_,B>, ui: &mut dyn UI, command: &str)
             let mut flags = parse_flags(&(expressions[2]), "gpnl")?;
             let g = flags.remove(&'g').unwrap();
             p = flags.remove(&'p').unwrap();
-            // TODO, regex in 'n' and 'l'
+            n = flags.remove(&'n').unwrap();
+            l = flags.remove(&'l').unwrap();
             let substituted = substitute::substitute(expressions[1]);
             state.selection = Some(
               state.buffer.search_replace((expressions[0], &substituted), selection, g)?
